@@ -40,7 +40,6 @@ class Mojitos:
         self.load = len(sensor_set & load_names) != 0    
         self.infiniband = len(sensor_set & infiniband_names) != 0    
         
-        self.net_dev = None
         self.executor = None
 
         self.names = sensor_set
@@ -63,6 +62,7 @@ class Mojitos:
         else:
             executor.local('cd /tmp/mojitos; git pull')
         executor.local('cd /tmp/mojitos; make')
+        executor.local('cp /tmp/mojitos/mojitos /tmp/bin/')
         if True or self.rapl:
             if read_int('/proc/sys/kernel/perf_event_paranoid') != 0:
                 executor.hosts("sh -c 'echo 0 >/proc/sys/kernel/perf_event_paranoid'", root=True)
@@ -71,15 +71,13 @@ class Mojitos:
                 executor.hosts("chmod a+rw /sys/class/powercap/intel-rapl/*/*", root=True)
                 executor.hosts("chmod a+rw /sys/class/powercap/intel-rapl/*/*/*", root=True)
 
-        if self.network:
-            self.net_dev = executor.get_network_if()
         self.executor = executor
 
-        self.cmdline = '/tmp/mojitos/mojitos -t 0 -f %s' % self.frequency
+        self.cmdline = '/tmp/bin/mojitos -t 0 -f %s' % self.frequency
         if self.perf:
             self.cmdline += ' -p ' + ','.join(self.names & perf_names)
         if self.network:
-            self.cmdline += ' -d %s' % self.net_dev
+            self.cmdline += ' -d X'
         if self.infiniband:
             self.cmdline += ' -i X'
         if self.rapl:
@@ -91,15 +89,20 @@ class Mojitos:
 
     def start(self):
         'Starts the monitoring right before the benchmark'
-        self.executor.local(self.cmdline)
+        self.executor.hosts(self.cmdline)
 
     def stop(self):
         'Stops the monitoring right before the benchmark'
-        self.executor.local('killall mojitos')
+        self.executor.hosts('killall mojitos')
 
     def save(self, experiment, benchname, beg_time):
         'Save the results when time is no more critical'
         filename_moj = experiment.output_file+'_mojitos'
         os.makedirs(filename_moj, exist_ok=True)
-        self.executor.local('mv /dev/shm/monitoring %s/%s_%s_%s' %
-                            (filename_moj, self.executor.hostnames[0], benchname, beg_time))
+        if len(self.executor.hostnames) > 1:
+            for hostname in self.executor.hostnames:
+                self.executor.local('oarcp %s:/dev/shm/monitoring %s/%s_%s_%s' %
+                                    (hostname, filename_moj, hostname, benchname, beg_time))
+        else:
+            self.executor.local('cp /dev/shm/monitoring %s/%s_%s_%s' %
+                                    (filename_moj, 'localhost', benchname, beg_time))
